@@ -32,6 +32,7 @@ gi.require_version('Vte', '2.91')  # vte-0.38
 from gi.repository import GLib
 from gi.repository import GObject
 from gi.repository import Gdk
+from gi.repository import Gio
 from gi.repository import Gtk
 from gi.repository import Keybinder
 from gi.repository import Pango
@@ -48,6 +49,7 @@ from guake.globals import ALIGN_LEFT
 from guake.globals import ALIGN_RIGHT
 from guake.globals import ALIGN_TOP
 from guake.globals import ALWAYS_ON_PRIMARY
+from guake.globals import MAX_TRANSPARENCY
 from guake.globals import NAME
 from guake.globals import QUICK_OPEN_MATCHERS
 from guake.globals import bindtextdomain
@@ -88,32 +90,28 @@ HOTKEYS = [
     {
         'label': _('General'),
         'key': 'general',
-        'keys': [
-            {
-                'key': 'show-hide',
-                'label': _('Toggle Guake visibility')
-            },
-            {
-                'key': 'show-focus',
-                'label': _('Show and focus Guake window')
-            },
-            {
-                'key': 'toggle-fullscreen',
-                'label': _('Toggle Fullscreen')
-            },
-            {
-                'key': 'toggle-hide-on-lose-focus',
-                'label': _('Toggle Hide on Lose Focus')
-            },
-            {
-                'key': 'quit',
-                'label': _('Quit')
-            },
-            {
-                'key': 'reset-terminal',
-                'label': _('Reset terminal')
-            },
-        ]
+        'keys': [{
+            'key': 'show-hide',
+            'label': _('Toggle Guake visibility')
+        }, {
+            'key': 'show-focus',
+            'label': _('Show and focus Guake window')
+        }, {
+            'key': 'toggle-fullscreen',
+            'label': _('Toggle Fullscreen')
+        }, {
+            'key': 'toggle-hide-on-lose-focus',
+            'label': _('Toggle Hide on Lose Focus')
+        }, {
+            'key': 'quit',
+            'label': _('Quit')
+        }, {
+            'key': 'reset-terminal',
+            'label': _('Reset terminal')
+        }, {
+            'key': 'search-terminal',
+            'label': _('Search terminal')
+        }]
     },
     {
         'label': _('Tab management'),
@@ -123,6 +121,10 @@ HOTKEYS = [
                 'key': 'new-tab',
                 'label': _('New tab')
             },
+            {
+                'key': 'new-tab-home',
+                'label': _('New tab in home directory')
+            },
             {
                 'key': 'close-tab',
                 'label': _('Close tab')
@@ -133,6 +135,56 @@ HOTKEYS = [
             },
         ]
     },
+    {
+        'label': _('Split management'),
+        'key': 'split',
+        'keys': [
+            {
+                'key': 'split-tab-vertical',
+                'label': _('Split tab vertical')
+            },
+            {
+                'key': 'split-tab-horizontal',
+                'label': _('Split tab horizontal')
+            },
+            {
+                'key': 'close-terminal',
+                'label': _('Close terminal')
+            },
+            {
+                'key': 'focus-terminal-up',
+                'label': _('Focus terminal above')
+            },
+            {
+                'key': 'focus-terminal-down',
+                'label': _('Focus terminal below')
+            },
+            {
+                'key': 'focus-terminal-left',
+                'label': _('Focus terminal on the left')
+            },
+            {
+                'key': 'focus-terminal-right',
+                'label': _('Focus terminal on the right')
+            },
+            {
+                'key': 'move-terminal-split-up',
+                'label': _('Move the terminal split handle up')
+            },
+            {
+                'key': 'move-terminal-split-down',
+                'label': _('Move the terminal split handle down')
+            },
+            {
+                'key': 'move-terminal-split-right',
+                'label': _('Move the terminal split handle right')
+            },
+            {
+                'key': 'move-terminal-split-left',
+                'label': _('Move the terminal split handle left')
+            },
+        ]
+    },
     {
         'label': _('Navigation'),
         'key': 'nav',
@@ -287,7 +339,7 @@ def refresh_user_start(settings):
             os.remove(desktop_file)
 
 
-class PrefsCallbacks(object):
+class PrefsCallbacks():
 
     """Holds callbacks that will be used in the PrefsDialg class.
     """
@@ -298,6 +350,21 @@ class PrefsCallbacks(object):
 
     # general tab
 
+    def on_restore_tabs_startup_toggled(self, chk):
+        """Changes the activity of restore-tabs-startup in dconf
+        """
+        self.settings.general.set_boolean('restore-tabs-startup', chk.get_active())
+
+    def on_restore_tabs_notify_toggled(self, chk):
+        """Changes the activity of restore-tabs-notify in dconf
+        """
+        self.settings.general.set_boolean('restore-tabs-notify', chk.get_active())
+
+    def on_save_tabs_when_changed_toggled(self, chk):
+        """Changes the activity of save-tabs-when-changed in dconf
+        """
+        self.settings.general.set_boolean('save-tabs-when-changed', chk.get_active())
+
     def on_default_shell_changed(self, combo):
         """Changes the activity of default_shell in dconf
         """
@@ -332,6 +399,11 @@ class PrefsCallbacks(object):
         """
         self.settings.general.set_boolean('use-popup', chk.get_active())
 
+    def on_workspace_specific_tab_sets_toggled(self, chk):
+        """Sets the 'workspace-specific-tab-sets' property in dconf
+        """
+        self.settings.general.set_boolean('workspace-specific-tab-sets', chk.get_active())
+
     def on_prompt_on_quit_toggled(self, chk):
         """Set the `prompt on quit' property in dconf
         """
@@ -546,6 +618,11 @@ class PrefsCallbacks(object):
         """
         self.settings.styleFont.set_boolean('allow-bold', chk.get_active())
 
+    def on_bold_is_bright_toggled(self, chk):
+        """Changes the value of bold_is_bright in dconf
+        """
+        self.settings.styleFont.set_boolean('bold-is-bright', chk.get_active())
+
     def on_font_style_font_set(self, fbtn):
         """Changes the value of font_style in dconf
         """
@@ -556,7 +633,7 @@ class PrefsCallbacks(object):
         """
         value = hscale.get_value()
         self.prefDlg.set_colors_from_settings()
-        self.settings.styleBackground.set_int('transparency', int(value))
+        self.settings.styleBackground.set_int('transparency', MAX_TRANSPARENCY - int(value))
 
     # compatibility tab
 
@@ -679,8 +756,9 @@ class PrefsDialog(SimpleGladeApp):
         treeview.set_model(self.store)
         treeview.set_rules_hint(True)
 
-        # TODO PORT this is killing the editing of the accl
-        # treeview.connect('button-press-event', self.start_editing)
+        treeview.connect('button-press-event', self.start_editing)
+
+        treeview.set_activate_on_single_click(True)
 
         renderer = Gtk.CellRendererText()
         column = Gtk.TreeViewColumn(_('Action'), renderer, text=1)
@@ -698,7 +776,13 @@ class PrefsDialog(SimpleGladeApp):
         column.add_attribute(renderer, "accel-key", 1)
         treeview.append_column(column)
 
-        self.demo_terminal = GuakeTerminal(self.window, self.settings)
+        class fake_guake():
+            pass
+
+        fg = fake_guake()
+        fg.window = self.window
+        fg.settings = self.settings
+        self.demo_terminal = GuakeTerminal(fg)
         self.demo_terminal_box = self.get_widget('demo_terminal_box')
         self.demo_terminal_box.add(self.demo_terminal)
 
@@ -706,6 +790,11 @@ class PrefsDialog(SimpleGladeApp):
 
         self.demo_terminal.pid = pid
 
+        self.settings.general.bind(
+            'tab-close-buttons', self.get_widget('tab-close-buttons'), 'active',
+            Gio.SettingsBindFlags.DEFAULT
+        )
+
         self.populate_shell_combo()
         self.populate_keys_tree()
         self.populate_display_n()
@@ -944,7 +1033,6 @@ class PrefsDialog(SimpleGladeApp):
         if hook_show_widget is not None:
             if hook_show_setting is not None:
                 hook_show_widget.set_text(hook_show_setting)
-        return
 
     def _load_default_shell_settings(self):
         combo = self.get_widget('default_shell')
@@ -967,7 +1055,7 @@ class PrefsDialog(SimpleGladeApp):
         if dest_screen > n_screens - 1:
             self.settings.general.set_boolean('mouse-display', False)
             dest_screen = screen.get_primary_monitor()
-            self.settings.general.set_int('display_n', dest_screen)
+            self.settings.general.set_int('display-n', dest_screen)
 
         if dest_screen == ALWAYS_ON_PRIMARY:
             first_item = combo.get_model().get_iter_first()
@@ -988,6 +1076,18 @@ class PrefsDialog(SimpleGladeApp):
         """
         self._load_default_shell_settings()
 
+        # restore tabs startup
+        value = self.settings.general.get_boolean('restore-tabs-startup')
+        self.get_widget('restore-tabs-startup').set_active(value)
+
+        # restore tabs notify
+        value = self.settings.general.get_boolean('restore-tabs-notify')
+        self.get_widget('restore-tabs-notify').set_active(value)
+
+        # save tabs when changed
+        value = self.settings.general.get_boolean('save-tabs-when-changed')
+        self.get_widget('save-tabs-when-changed').set_active(value)
+
         # login shell
         value = self.settings.general.get_boolean('use-login-shell')
         self.get_widget('use_login_shell').set_active(value)
@@ -1000,6 +1100,10 @@ class PrefsDialog(SimpleGladeApp):
         value = self.settings.general.get_boolean('use-popup')
         self.get_widget('use_popup').set_active(value)
 
+        # workspace-specific tab sets
+        value = self.settings.general.get_boolean('workspace-specific-tab-sets')
+        self.get_widget('workspace-specific-tab-sets').set_active(value)
+
         # prompt on quit
         value = self.settings.general.get_boolean('prompt-on-quit')
         self.get_widget('prompt_on_quit').set_active(value)
@@ -1159,6 +1263,10 @@ class PrefsDialog(SimpleGladeApp):
         value = self.settings.styleFont.get_boolean('allow-bold')
         self.get_widget('allow_bold').set_active(value)
 
+        # use bold is bright
+        value = self.settings.styleFont.get_boolean('bold-is-bright')
+        self.get_widget('bold_is_bright').set_active(value)
+
         # palette
         self.fill_palette_names()
         value = self.settings.styleFont.get_string('palette-name')
@@ -1176,7 +1284,7 @@ class PrefsDialog(SimpleGladeApp):
         self.set_cursor_blink_mode(value)
 
         value = self.settings.styleBackground.get_int('transparency')
-        self.get_widget('background_transparency').set_value(value)
+        self.get_widget('background_transparency').set_value(MAX_TRANSPARENCY - value)
 
         value = self.settings.general.get_int('window-valignment')
         self.get_widget('top_align').set_active(value)
@@ -1300,8 +1408,8 @@ class PrefsDialog(SimpleGladeApp):
 
         # avoiding problems with common keys
         if ((mods == 0 and key != 0) and
-            ((key >= ord('a') and key <= ord('z')) or (key >= ord('A') and key <= ord('Z')) or
-             (key >= ord('0') and key <= ord('9')))):
+            ((ord('a') <= key <= ord('z')) or (ord('A') <= key <= ord('Z')) or
+             (ord('0') <= key <= ord('9')))):
             dialog = Gtk.MessageDialog(
                 self.get_widget('config-window'),
                 Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
@@ -1321,7 +1429,7 @@ class PrefsDialog(SimpleGladeApp):
 
         self.store[path][HOTKET_MODEL_INDEX_HUMAN_ACCEL] = keylabel
 
-        if dconf_path == "show-hide" or dconf_path == "show-focus":
+        if dconf_path in ("show-hide", "show-focus"):
             self.settings.keybindingsGlobal.set_string(dconf_path, accelerator)
         else:
             self.settings.keybindingsLocal.set_string(dconf_path, accelerator)
@@ -1353,30 +1461,20 @@ class PrefsDialog(SimpleGladeApp):
 
         Thanks to gnome-keybinding-properties.c =)
         """
-        # TODO PORT some thing in here is breaking stuff
-
-        if event.window != treeview.get_bin_window():
-            return False
-
         x, y = int(event.x), int(event.y)
         ret = treeview.get_path_at_pos(x, y)
         if not ret:
             return False
 
         path, column, cellx, celly = ret
-        if path and len(path) > 1:
 
-            def real_cb():
-                treeview.grab_focus()
-                treeview.set_cursor(path, column, True)
+        treeview.row_activated(path, Gtk.TreeViewColumn(None))
+        treeview.set_cursor(path)
 
-            treeview.stop_emission('button-press-event')
-            GObject.idle_add(real_cb)
-
-        return True
+        return False
 
 
-class KeyEntry(object):
+class KeyEntry():
 
     def __init__(self, keycode, mask):
         self.keycode = keycode
