@@ -36,6 +36,7 @@ fi
 if [[ $RUN == "1" ]]; then
     echo "Install packages needed for execution"
     sudo pacman -S \
+		libwnck3 \
         libkeybinder3 \
         libnotify \
         python-cairo \
@@ -51,7 +52,8 @@ if [[ $MAKE == "1" ]]; then
         gettext \
         gsettings-desktop-schemas \
         make \
-        pandoc
+        pandoc \
+        python-pipenv
 fi
 
 if [[ $DEV == "1" ]]; then
